[−][src]Struct aimc_hal::automation::All
A combinator which combines many AutomationSequences and will poll them
all to completion, stopping when either a fault is raised or there are no
more incomplete sequences.
Examples
use aimc_hal::automation::{AutomationSequence, Transition, All}; /// A simple automation sequence which will return `Transition::Incomplete` /// until it reaches zero. struct CountDown(usize); impl<I, O> AutomationSequence<I, O> for CountDown { type FaultInfo = (); fn poll(&mut self, inputs: &I, outputs: &mut O) -> Transition<()> { if self.0 == 0 { Transition::Complete } else { self.0 -= 1; Transition::Incomplete } } } // Combine the sequences into one big automation sequence let mut seq = All::new([CountDown(1), CountDown(5), CountDown(2)]); // we'll keep track of the number of polls let mut polls = 0; // keep polling until all the timers have reached zero while seq.poll(&(), &mut ()) != Transition::Complete { polls += 1; } // we should have polled 5 times (`max(1, 5, 2)`) assert_eq!(polls, 5);
Implementations
impl<A, const N: usize> All<A, { N }>[src]